<?php
namespace Teknisa\FAI\Modules\Apuracao\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DataSource\FilterCriteria;

class FAI04301AcompanhamentoFaturacao extends \Zeedhi\Framework\Controller\Report {

    protected $environment;
	protected $parameterBagColumns;
    protected $crudService;
    protected $novoCodigo;
    protected $birtStrategy;

    public function __construct(ReportService $reportService, $environment, $crudService, $novoCodigo,$birtStrategy) {
        $this->environment = $environment;
        $this->crudService = $crudService;
        $this->novoCodigo  = $novoCodigo;
        $this->birtStrategy   = $birtStrategy;
        parent::__construct($reportService);
       
    }

    protected $reportMapping = array (
        'fai04300' => array (
            'strategy' => 'BIRT',
            'parameterMapping' =>
            array (
                'CDFILIAL'    => 'P_CDFILIAL',
                'DTPERINI'    => 'P_DTPERINI',
                'DTPERFIN'    => 'P_DTPERFIN',
                'CLIENPRIN'   => 'P_CLIENPRIN',
                'NRORG'       => 'P_NRORG'
            )
        ),
        'fai04301' => array (
            'strategy' => 'BIRT',
            'parameterMapping' =>
            array (
                'NRLISTA'     => 'P_NRLISTAFILI',
                'DTPERINI'    => 'P_DTPERINI',
                'DTPERFIN'    => 'P_DTPERFIN',
                'CLIENPRIN'   => 'P_CLIENPRIN',
                'NRORG'       => 'P_NRORG'
            )
        )
    );

    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {

        $row = $request->getRow();
        $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
        
        $row['NRORG'] = $this->environment->getNrorg();
        $row['CDGRUPFILI'] = empty($row['CDGRUPFILI']) ? null : $row['CDGRUPFILI'];
        $row['CDFILIAL'] = $row['ALL_CDFILIAL'] ? implode("_", $this->findAgrupamento($row)) : implode("_", $row['CDFILIAL']);
        if($row['RELATORIO'] == 'fai04301') $row['NRLISTA'] = $this->insertLista($row['CDFILIAL']);
        
    }
    
    private function findAgrupamento($row){
		$conditions = array (
			array (
				"columnName" 	=> "CDOPERADOR",
				"operator" 		=> "=",
				"value" 		=> $this->environment->getCdOperador()
			),
			array (
         		"columnName" 	=> "CDGRUPFILI",
         		"operator" 		=> "=",
         		"value" 		=> $row['CDGRUPFILI']
             ),
            array (
                "columnName" 	=> "IDCNTRRESC",
                "operator" 		=> "=",
                "value" 		=> 'N'
            ),
         	array(
         	    "columnName" 	=> "NRORG",
         		"operator" 		=> "=",
         		"value" 		=>  $this->environment->getNrOrg()
         	)
		);
		$this->parameterBagColumns = array ("CDOPERADOR", "CDGRUPFILI", "NRORG");
       	$dataSet = $this->crudService->getFilteredDataSet("filial_filioper_grupfili", $conditions);
       	return array_column($dataSet->getRows(), 'CDFILIAL');
    }

    private function insertLista($rows){
        $rows = explode("_", $rows);
        $dataSourceName = 'lista';
        $nrorg = $this->environment->getNrOrg();
        $nrlista = $this->novoCodigo->getCodeByTableName($dataSourceName, $nrorg);;
        $registros = array();
        foreach ($rows as $row) {
            if(!empty($row)){
                $row = array(
                    "NRLISTA"  => $nrlista,
                    "CDLISTA"  => $row,
                    "__is_new" => true,
                    "NRORG"    => $nrorg
                );
                array_push($registros, $row);
            }
        }
        
        $dataSet = new DataSet($dataSourceName, $registros);
        $request = new DTO\Request\DataSet($dataSet, "", "", "");
        $rowsToSave = $this->crudService->getRowsToSave($request, $dataSourceName);
        $this->crudService->save($dataSourceName, $rowsToSave);
        
        return $nrlista;
	}
}