<?php
namespace Teknisa\FAI\Modules\Tabelas\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use TecFood\Services\User as UserService;

class Fai04800CentralFaturamentoController {
    
    protected $connection;

    public function __construct($connection) {
        $this->connection = $connection;
    }
    
    public function saveUnidade(DTO\Request $request, DTO\Response $response){
        $rows = $request->getDataSet()->getRows();
        
        $codCentral = $rows[0]->get('CDFILIAL_CENTRAL');
        
        $this->saveUnidadeCentral(array("CDFILIAL" => $codCentral));
        
        foreach($rows as $row){
            if(isset($row['CDFILIAL_AGREGADA'])){
                $data = array(
                    "CDFILIAL" => $row->get('CDFILIAL_AGREGADA'),
                    "CDFILCENTRALFATU" => $codCentral
                );
                
                $this->saveUnidadeAgregada($data);
            }
        }
        
    }
    
    public function saveUnidadeCentral($codFilial){
        $sql = "UPDATE FILIAL
            SET IDCENTRALFATU = 'S', CDFILCENTRALFATU = ''
            WHERE CDFILIAL = :CDFILIAL";
            
        
        try {
            $std = $this->connection->prepare($sql);
            $std->execute($codFilial);
            
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function saveUnidadeAgregada($data){
        $sql = "UPDATE FILIAL
            SET CDFILCENTRALFATU = :CDFILCENTRALFATU
            WHERE CDFILIAL = :CDFILIAL";
            
        
        try {
            $std = $this->connection->prepare($sql);
            $std->execute($data);
            
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function deleteUnidadeCentral(DTO\Request $request, DTO\Response $response){
        $rows = $request->getDataSet()->getRows();
        
        $sql = "UPDATE FILIAL
            SET IDCENTRALFATU = 'N'
            WHERE CDFILIAL = :CDFILIAL";
        
        foreach($rows as $row){
            $data = array(
                "CDFILIAL" => $row->get('CDFILIAL')
            );
            
            try {
                $std = $this->connection->prepare($sql);
                $std->execute($data);
                
            } catch (Exception $e) {
                throw $e;
            }
            
            $this->deleteUnidadeAgregadaByCentral($data);
        }
        
        
    }

    public function deleteUnidadeAgregada(DTO\Request $request, DTO\Response $response){
        $rows = $request->getDataSet()->getRows();
        
        $sql = "UPDATE FILIAL
            SET CDFILCENTRALFATU = ''
            WHERE CDFILIAL = :CDFILIAL";
        
        foreach($rows as $row){
            $data = array(
                "CDFILIAL" => $row->get('CDFILIAL')
            );
            
            try {
                $std = $this->connection->prepare($sql);
                $std->execute($data);
                
            } catch (Exception $e) {
                throw $e;
            }
            
        }
        
        
    }
    
    public function deleteUnidadeAgregadaByCentral($data){
        
        $sql = "UPDATE FILIAL
            SET CDFILCENTRALFATU = ''
            WHERE CDFILCENTRALFATU = :CDFILIAL";
        
        try {
            $std = $this->connection->prepare($sql);
            $std->execute($data);
            
        } catch (Exception $e) {
            throw $e;
        }    
    }

}
